%--------------------------------------------------------------------------
%   PROCESS PRESSURE-AREA CURVES
%   Compared with ISO curve and 3[m^2] Pond Inlet
%--------------------------------------------------------------------------

cd('MAPPE/PPAC')
plotsam
cd('../')
cd('../')
cd('MAPPE\FORCE\Pond Inlet')
plot_force
cd('../')
cd('../')
cd('../')

TUL10 = load('TUL10/ANALYSE_REP/VARIABLES/WS.mat','p_pa_c',...
    'asum_cont_area', 'x_axis','ISO','indent','MN_F');
TUL5 = load('TUL5/ANALYSE_REP/VARIABLES/WS.mat','p_pa_c',...
    'asum_cont_area', 'x_axis','ISO','indent','MN_F','asum_cont_area',...
    'area_ratio');
TUL5_NO_RAND = load('TUL5_NO_RAND/ANALYSE_REP/VARIABLES/WS.mat',...
    'p_pa_c','asum_cont_area', 'x_axis','ISO','indent','MN_F',...
    'asum_cont_area','area_ratio');
TUL5_DOUBLE = load('TUL5_DOUBLE/ANALYSE_REP/VARIABLES/WS.mat','p_pa_c',...
    'asum_cont_area', 'x_axis','ISO','indent','MN_F');
TUL1 = load('TUL1/ANALYSE_REP/VARIABLES/WS.mat','p_pa_c',...
    'asum_cont_area', 'x_axis','ISO','indent','MN_F');
TUL3 = load('TUL3/ANALYSE_REP/VARIABLES/WS.mat','p_pa_c',...
    'asum_cont_area', 'x_axis','ISO','indent','MN_F');

%%
TUL10in = TUL10.indent*1000;
TUL10in(TUL10in == 0) = NaN;
forc_10 = abs(TUL10.MN_F);
forc_10(forc_10 == 0) = NaN;

TUL5in = TUL5.indent*1000;
TUL5in(TUL5in == 0) = NaN;
forc_5 = abs(TUL5.MN_F);
forc_5(forc_5 == 0) = NaN;

TUL5_NO_RANDin = TUL5_NO_RAND.indent*1000;
TUL5_NO_RANDin(TUL5_NO_RANDin == 0) = NaN;
forc_NO_RAND = abs(TUL5_NO_RAND.MN_F);
forc_NO_RAND(forc_NO_RAND == 0) = NaN;

TUL5_DOUBLEin = TUL5_DOUBLE.indent*1000;
TUL5_DOUBLEin(TUL5_DOUBLEin == 0) = NaN;
forc_DOUBLE = abs(TUL5_DOUBLE.MN_F);
forc_DOUBLE(forc_DOUBLE == 0) = NaN;

TUL1in = TUL1.indent*1000;
TUL1in(TUL1in == 0) = NaN;
forc_1 = abs(TUL1.MN_F);
forc_1(forc_1 == 0) = NaN;

TUL3in = TUL3.indent*1000;
TUL3in(TUL3in == 0) = NaN;
forc_3 = abs(TUL3.MN_F);
forc_3(forc_3 == 0) = NaN;

%%

figure(199)
ploty = plot(TUL5_NO_RAND.asum_cont_area, abs(TUL5_NO_RAND.area_ratio),...
    'r',TUL5.asum_cont_area, abs(TUL5.area_ratio),'b')   

title('Actual area vs Nominal area')
xlabel('Area [m^2]')
ylabel({'Area-ratio';'Actual/Nominal';'[MPa]'})
set(gcf,'color','w');
box on
hold off
legend([ploty],'NO Variation','Medium 1 Variation')

print -dpng FIGURES\AREA_RATIO_COMPARE.png -r600
%%
figure(30)
title('Process prssure-area curve compared with Pond Inlet and ISO')
p_1 =   plot(cur1(:,1), cur1(:,2),'g-',cur2(:,1),cur2(:,2),'g-',...
        cur3(:,1),cur3(:,2),'g-',cur4(:,1),cur4(:,2),'g-')
        hold on
        
p_2 =   plot(TUL5.x_axis,TUL5.ISO,'r+',...
    TUL5_NO_RAND.asum_cont_area, abs(TUL5_NO_RAND.p_pa_c),'c',...
        TUL1.asum_cont_area, abs(TUL1.p_pa_c),'m',...        
        TUL5_DOUBLE.asum_cont_area, abs(TUL5_DOUBLE.p_pa_c),'r',...
        TUL10.asum_cont_area, abs(TUL10.p_pa_c),'b',...
        TUL3.asum_cont_area, abs(TUL3.p_pa_c),'y',...
        TUL5.asum_cont_area, abs(TUL5.p_pa_c),'black')
        

axis([ 0 3 0 25])
set(p_2,'LineWidth',1.5)
set(p_1,'LineWidth',1.5)
set(gcf,'color','w');
legend([p_2],'ISO curve','NO Variation','Low Variation',...
    'Large Variation','Xtra Large Variation','Medium 2 Variation',...
    'Medium 1 Variaton')
hold off

print -dpng FIGURES\PPAC_COMPARE.png -r600
%%
figure(10)
pl_0 = plot(x_pen1,z1_1);
set(pl_0,'LineWidth',1, 'color',[0 0.7 0])

pl_1 = plot(x_pen2,z1_2,x_pen3,z1_3, x_pen4,z1_4);
set(pl_1,'LineWidth',1, 'color',[0 0.7 0])
hold on



pl_2 = plot(TUL5_NO_RANDin,forc_NO_RAND,'c',...
    TUL1in,forc_1,'m',...
    TUL5_DOUBLEin,forc_DOUBLE,'r',...
    TUL10in,forc_10,'b',...
    TUL3in,forc_3,'y',...
    TUL5in,forc_5,'black')
set(pl_2,'LineWidth',1.5)
set(gcf,'color','w');
legend([pl_2],'NO Variation','Low Variation','Large Variation',...
    'Xtra large Variation','Mediium 2 Variation','Medium 1 Variation')

axis([0 250 0 max(max(max(z1_1),max(z1_2)),max(max(z1_3),max(z1_4)))])

print -dpng FIGURES\FORCE_COMPARE.png -r600