%**************************************************************************
%               Post-Processing LS-DYNA Results SCRIPT
%**************************************************************************
%                 Post-processing of the MATSUM-FILE
%**************************************************************************
% PART 1: Read MATSUM-file
% PART 2: Calculate different energies
% PART 3: ENERGY CURVES PLOTSENERGIES
%**************************************************************************
%------------------------------->>        DEVELOPED BY: SIMEN BHLERENGEN
%**************************************************************************
% MAKE USE OF A WORD-COUNT FUNCTION:
NR_TS = wordcount2('matsum');   % counts number of the word = time
                                % gives number of time-step
                                
%%
close all
%**************************************************************************
% PART 1: READ IN MATSUM-FILE
%**************************************************************************
fid = fopen('matsum');
for i=1:5
    tline = fgets(fid);
end

b = fscanf(fid,'%d %*s',[1,inf]);
NR_MAT = length(b);
tline = fgets(fid);

TIME = zeros(1,NR_TS);
values = zeros(NR_MAT,11,NR_TS);
for t = 1:NR_TS
    for i = 1:3
        tline = fgets(fid);
    end
TIME(t) = fscanf(fid,'%*s %*c %f',[1,1]);
for m = 1:NR_MAT
    fscanf(fid,'%*s %s',[1,1]);
    values(m,1:11,t) = fscanf(fid,'%*s %f',[1,11]);    
    tline = fgets(fid);
    tline = fgets(fid);
end
end
fclose(fid);

%**************************************************************************
% PART 2: Calculate Different ENERGIES from LS-DYNA ANALYSIS
%**************************************************************************
Etot = zeros(NR_MAT,NR_TS);
Ekin = zeros(NR_MAT,NR_TS);
Eint = zeros(NR_MAT,NR_TS);
Eero_int = zeros(NR_MAT,NR_TS);
Eero_kin = zeros(NR_MAT,NR_TS);
Ehge = zeros(NR_MAT,NR_TS);
Eint_tot = zeros(NR_MAT,NR_TS);
Ekin_tot = zeros(NR_MAT,NR_TS);
Etot_totm = zeros(1,NR_TS);
Ekin_totm = zeros(1,NR_TS);
Eint_totm = zeros(1,NR_TS);

Eship_tot = zeros(1,NR_TS);
Eship_kin = zeros(1,NR_TS);
Eship_int = zeros(1,NR_TS);
Eship_ero_int = zeros(1,NR_TS);
Eship_ero_kin = zeros(1,NR_TS);
Eship_hge = zeros(1,NR_TS);
Eship_int_tot = zeros(1,NR_TS);
Eiceberg_tot = zeros(1,NR_TS);
Eiceberg_kin = zeros(1,NR_TS);
Eiceberg_int = zeros(1,NR_TS);
Eiceberg_ero_int = zeros(1,NR_TS);
Eiceberg_ero_kin = zeros(1,NR_TS);
Eiceberg_hge = zeros(1,NR_TS);
Eiceberg_int_tot = zeros(1,NR_TS);

for t = 1:NR_TS
    for m = 1:NR_MAT
Ekin(m,t) = Ekin(m,t) + values(m,2,t);
Eint(m,t) = Eint(m,t) + values(m,1,t);
Eero_int(1,t) = Eero_int(1,t) + values(m,3,t);
Eero_kin(1,t) = Eero_kin(1,t) + values(m,4,t);
Ehge(m,t) = Ehge(m,t) + values(m,11,t);

Ekin_tot(m,t) = Ekin_tot(m,t) + values(m,2,t) + values(m,4,t);
Eint_tot(m,t) = Eint_tot(m,t) + values(m,1,t) + values(m,3,t);

Etot(m,t) = Etot(m,t) + values(m,1,t) + values(m,2,t) +...
    values(m,11,t) + values(m,3,t) + values(m,4,t);

   end
Etot_totm(1,t) = Etot_totm(1,t) + sum(Etot(:,t));
Ekin_totm(1,t) = Ekin_totm(1,t) + sum(Ekin(:,t));
Eint_totm(1,t) = Eint_totm(1,t) + sum(Eint(:,t));

% NB! ICEBERG MODEL NEED TO BE MATERIAL 1 AND 2!

%SHIP ENERGIES:
Eship_tot(t) = sum(Etot(3:end,t));          % TOTAL ENERGY
Eship_int(t) = sum(Eint(3:end,t));          % INTERNAL
Eship_ero_int(t) = sum(Eero_int(3:end,t));  % ERODED INTERNAL
Eship_int_tot(t) = sum(Eint_tot(3:end,t));  % TOTAL INTERNAL
Eship_kin(t) = sum(Ekin(3:end,t));          % KINETIC
Eship_ero_kin(t) = sum(Eero_kin(3:end,t));  % ERODED KINETIC
Eship_hge(t) = sum(Ehge(3:end,t));          % HOURGLASS
%ICEBERG ENERGIES:
Eiceberg_tot(t) = sum(Eint(1:2,t));         % TOTAL ENERGY
Eiceberg_int(t) = sum(Eint(1:2,t));          % INTERNAL
Eiceberg_ero_int(t) = sum(Eero_int(1:2,t));  % ERODED INTERNAL
Eiceberg_int_tot(t) = sum(Eint_tot(1:2,t));  % TOTAL INTERNAL
Eiceberg_kin(t) = sum(Ekin(1:2,t));          % KINETIC
Eiceberg_ero_kin(t) = sum(Eero_kin(1:2,t));  % ERODED KINETIC
Eiceberg_hge(t) = sum(Ehge(1:2,t));          % HOURGLASS
end

%TRANSFORM UNIT FROM PA -> MPa:
Ekin = Ekin*10^-6;
Eint =Eint*10^-6;
Eero_int = Eero_int*10^-6;
Eero_kin  = Eero_kin*10^-6;
Ehge = Ehge*10^-6;
Ekin_tot = Ekin_tot*10^-6;
Eint_tot = Eint_tot*10^-6;
Etot_totm =Etot_totm*10^-6;
Ekin_totm = Ekin_totm*10^-6;
Eint_totm = Eint_totm*10^-6;

%SHIP:
Eship_tot = Eship_tot*10^-6;
Eship_int = Eship_int*10^-6;
Eship_ero_int =Eship_ero_int*10^-6;
Eship_int_tot = Eship_int_tot*10^-6;
Eship_kin = Eship_kin*10^-6;
Eship_ero_kin = Eship_ero_kin*10^-6;
Eship_hge = Eship_hge*10^-6;
%ICEBERG:
Eiceberg_tot = Eiceberg_tot*10^-6;
Eiceberg_int = Eiceberg_int*10^-6;
Eiceberg_ero_int = Eiceberg_ero_int*10^-6;
Eiceberg_int_tot = Eiceberg_int_tot*10^-6;
Eiceberg_kin = Eiceberg_kin*10^-6;
Eiceberg_ero_kin = Eiceberg_ero_kin*10^-6;
Eiceberg_hge = Eiceberg_hge*10^-6;

% PRODUCING X-axis for the ship graphs:
NEG_TIME = -TIME;

%%
%**************************************************************************
% PART 3: ENERGY CURVES PLOTSENERGIES
%**************************************************************************
% RELATIVE STRENGTH BETWEEN STRUCTURE AND ICEBERG PLOT:
%--------------------------------------------------------------------------
figure(100)
centeraxes(gca,0);
set(gcf,'color','w');
plot(NEG_TIME,Eship_int_tot,'r-',TIME,Eiceberg_int_tot,'b-', 'LineWidth',1)
title('SHIP (RIGHT SIDE)     VS      ICEBERG (LEFT SIDE)')
xlabel('Time [s]')
ylabel('Energy [MPa]')
opt.fontname = 'helvetica';
opt.fontsize = 8;
centeraxes(gca,opt);
box on
hold off

%%
print -dpng FIGURES\MATSUM_F01_RELATIVE_STRENGTH.png -r600
%%
% INTERNAL ENERGY PLOTS:
%--------------------------------------------------------------------------
figure(2)
plot(TIME,Eint_tot(1,:),'r-',TIME,Eint(1,:),'b-', TIME,Eero_int(1,:),'m-','LineWidth',1)
title('Total internal energy vs Internal energy vs Eroded internal energy')
set(gcf,'color','w');
legend('Total internal energy','Internal energy','Eroded internal energy')
xlabel('Time [s]')
ylabel('Energy [MPa]')
box on
hold off
%%
print -dpng FIGURES\MATSUM_F01_INT_EN_and_HG_EN.png -r600
%%

figure(3)
plot(TIME,Ehge(1,:),'r-', TIME, Eint(1,:),'b-','LineWidth',1)
title('Hourglass energy VS Internal total')
legend('Hourglass energy','Internal energy')
xlabel('Time [s]')
ylabel('Energy [MPa]')
set(gcf,'color','w');
box on
hold off
%%
print -dpng FIGURES\MATSUM_F02_INT_EN_NotEROD_and_HG_EN.png.png -r600
%%
figure(4)
plot(TIME,Ehge(1,:),'r-', TIME, Eint_tot(1,:),'b-','LineWidth',1)
title('Hourglass energy VS total Internal energy')
set(gcf,'color','w');
xlabel('Time [s]')
ylabel('Energy [MPa]')
legend('Hourglass energy','Total internal energy')
box on
hold off

%%
print -dpng FIGURES\MATSUM_F03_Eint_tot_VS_Ehge.png -r600
%%
% HOURGLASS ENERGY PLOT:
%%-------------------------------------------------------------------------
figure(5)
plot(TIME,Ehge(1,:),'b-','LineWidth',1)
title('Hourglass energy')
xlabel('Time [s]')
ylabel('Energy [MPa]')
set(gcf,'color','w');
box on
hold off
%%
% TOTAL ENERGY ALL Materials PLOTS:
%%-------------------------------------------------------------------------
figure(7)
plot(TIME,Etot_totm,'b-',TIME,Ehge(1,:),'r-','LineWidth',1)
title('Total energy for all materials VS Hourglass energy')
legend('Total energy for all materials','Hourglass energy')
xlabel('Time [s]')
ylabel('Energy [MPa]')
set(gcf,'color','w');
box on
hold off
%%
print -dpng FIGURES\MATSUM_F04_TOT_EN_VS_HGEN.png -r600
%%
%**************************************************************************
% SAVING WORKPLACE!!!!
savefile =  'VARIABLES/MATSUM_WS.mat';
save(savefile)



