
%**************************************************************************
%               Post-Processing LS-DYNA Results SCRIPT
%**************************************************************************
%                   Post-processing of the NCFORC-FILE
%**************************************************************************
%                    RESULTS AND PLOTS of NCFORC-file
% PART 1: Actual vs Nominal area
% PART 2: Force vs indentation and time
% PART 3: Process pressure-area curve
% PART 4: Spatial pressure-area curves
% PART 5: Compare Process pressure-area curves
%**************************************************************************
%------------------------------->>        DEVELOPED BY: SIMEN BHLERENGEN
%**************************************************************************

% X-axis; for ISO curve:
x_axis = 0:10/(NR_TS-1):10;

z_axis = minH:Meshsize:maxH;
y_axis = minW:Meshsize:maxW;

% ISO Curve:
ISO = 7.40*x_axis.^(-0.70);

%%
%--------------------------------------------------------------------------
% PART 1: Actual area vs Nominal area
%--------------------------------------------------------------------------
nom_area = asum_cont_area;

figure(1)
plot(nom_area, area_ratio,'b-')
title('Actual area vs Nominal area')
xlabel('Area [m^2]')
ylabel({'Area-ratio';'Actual/Nominal';'[MPa]'})
set(gcf,'color','w');
box on
hold off

print -dpng FIGURES\NCFORC_F01_ACTUAL_VS_NOMINAL_AREA.png -r600

%% ------------------------------------------------------------------------
%       Force vs indentation and Time
%--------------------------------------------------------------------------

figure(2)
if exist('ax')==1
    cla 'reset'
else
end

set(gcf,'color','w');
box on
x1 = TIME;
y1 = abs(MN_F);
y2 = abs(MN_F);
x2 = indent;
hl1=line(x1,y1,'Color','r');
ylim([0 max(abs(MN_F))]);
ax(1)=gca;
set(ax(1),'Position',[0.12 0.12 0.75 0.70])
set(ax(1),'XColor','k','YColor','k');
xlabel('Time[s]')

ax(2)=axes('Position',get(ax(1),'Position'),...
   'XAxisLocation','top',...
   'YAxisLocation','left',...
   'Color','none',...
   'XColor','k','YColor','k');

hl2=line(x2,y2,'Color','r','Parent',ax(2));
ylim([0 max(abs(MN_F))]);
title({'Force vs Time and Indentation'})
box on

xlabel('Indentation [m]')
ylabel({'Force';'[MN]'})
hold off

print -dpng FIGURES\NCFORC_F02_FORCE_VS_TIME_AND_INDENTATION.png

%% ------------------------------------------------------------------------
% PART 2: Process pressure-area curve
%--------------------------------------------------------------------------

figure(3);

if exist('ax')==1
    cla 'reset'
else
end

set(gcf,'color','w');
box on
x1 = TIME;
y1 = abs(p_pa_c);
x2 = indent;
y2 = abs(p_pa_c);
hl1=line(x1,y1,'Color','k');
ylim([0 max(abs(p_pa_c))]);
ax(1)=gca;
set(ax(1),'Position',[0.12 0.12 0.75 0.70])
set(ax(1),'XColor','k','YColor','k');
xlabel('Time[s]')

ax(2)=axes('Position',get(ax(1),'Position'),...
   'XAxisLocation','top',...
   'YAxisLocation','left',...
   'Color','none',...
   'XColor','k','YColor','k');

hl2=line(x2,y2,'Color','r','Parent',ax(2));
ylim([0 max(abs(p_pa_c))]);
title({'Process prssure-area curve VS time and indentation'})
box on

xlabel('Indentation [m]')
ylabel({'Pressure';'[MPa]'})
hold off

print('-dpng', 'FIGURES\NCFORC_F03_PPAC_VS_TIME_AND_INDENTATION.png', '-r600')

%% ------------------------------------------------------------------------
% PART 3: Spatial PRESSURE-AREA CURVES
%--------------------------------------------------------------------------
% Method 1A,SPAC compared with PPAC and ISO Curve (ACTUAL AREA)
%--------------------------------------------------------------------------

figure(20)
set(gcf,'color','w');
box on
clear legendInfo
clear pl
cd('FUNCTIONS')
colorM = distinguishable_colors(length(locs));
cd('../')

for i = 1:length(locs)
    m1aa(:,i) = M1A.SA(:,i);
    m1aa(m1aa == 0) = NaN;
     
    p1 = colorM(i,1);
    p2 = colorM(i,2);
    p3 = colorM(i,3);
    
        m1asp(:,i) = abs(M1A.SP(:,i))*10^-6;
        m1asp(m1asp == 0) = NaN;

    pl(i) = plot(m1aa(:,i),m1asp(:,i),'Color', [p1 p2 p3],...
        'LineStyle', '-', 'LineWidth',2);
    hold on
    legendInfo{i} = ['TS = ' num2str(locs(i))];
    
end
    
    pl(i+1) = plot(act_area,abs(s_pa_c),'b.','markersize', 14);
    
    for i = 1:length(locs)
    plot(act_area(locs(i)), abs(s_pa_c(locs(i))),'gp','markersize', 10);
    hold on
    plot(act_area(locs(i)), abs(s_pa_c(locs(i))),'bo','markersize', 10);
    hold on
    plot(act_area(locs(i)), abs(s_pa_c(locs(i))),'r.','markersize', 20);
    hold on
    end
    
    pl(i+2) = plot(x_axis,ISO,'--r', 'MarkerSize',3, 'LineWidth',2);
    
title('Method 1A, SPACs compared with PPAC and ISO curve (ACTUAL AREA)')
axis([ 0 max(max(m1aa)) 0 max(max(max(m1asp)))])
    xlabel('Area [m^2]')
    ylabel('Pressure [MPa]')
    legendInfo{length(locs)+1} = 'PPA values';
    legendInfo{length(locs)+2} = 'ISO Curve';
    legend(pl,legendInfo)
    hold off

print -dpng FIGURES\NCFORC_F20_M1A_SPACs_CW_PPAC_AND_ISO_ACTUAL_AREA.png -r600
%%
choose_line = zeros(ant_max,length(locs));
sxs = zeros(length(locs),1);
sys = zeros(length(locs),1);

for i=1:length(locs)
for s=1:ant_max
        
choose_line(s,i) = sum(M1A.spac(s,:,i));
end
line_val = min(choose_line(:,i));
[sxs(i) sys(i)] = ind2sub(size(choose_line),find(choose_line==line_val));
end

figure(21)
cd('FUNCTIONS')
for i = 1:length(locs)
subplot_tight(ceil(sqrt((length(locs)/2))),...
    ceil(sqrt((length(locs)/2))),i, .025)
set(figure(21),'Units','Normalized','OuterPosition',[0 0 1 1]) 
pos=get(gca,'pos');
set(gca,'pos',[pos(1) pos(2) pos(3) pos(4)*0.95]);
pos=get(gca,'pos');
contourf(y_axis,z_axis,ar_con1a(:,:,sxs(i),i))
colorbar;
legend(num2str(locs(i)))
hc=colorbar('location','eastoutside','position',...
    [pos(1) pos(2)+pos(4) pos(3), 0.01]);
set(hc,'xaxisloc','top');
axis off
set(gca, 'color', [1 1 1])
set(gcf, 'color', [1 1 1])
end
hold off
cd('../')
  
print -dpng FIGURES\NCFORC_F21_M1A_CONTROL_AREA.png -r600

%% ------------------------------------------------------------------------
% Method 1B,SPAC compared with PPAC and ISO Curve (ACTUAL AREA)
%--------------------------------------------------------------------------
figure(22)
set(gcf,'color','w');
box on
clear legendInfo
clear pl
cd('FUNCTIONS')
colorM = distinguishable_colors(length(locs));
cd('../')

for i = 1:length(locs)
    m1ba(:,i) = M1B.SA(:,i);
    m1ba(m1ba == 0) = NaN;
     
    p1 = colorM(i,1);
    p2 = colorM(i,2);
    p3 = colorM(i,3);
    
        m1bsp(:,i) = abs(M1B.SP(:,i))*10^-6;
        m1bsp(m1bsp == 0) = NaN;

    pl(i) = plot(m1ba(:,i),m1bsp(:,i),'Color',...
        [p1 p2 p3], 'LineStyle', '-', 'LineWidth',2);
    hold on
    legendInfo{i} = ['TS = ' num2str(locs(i))];
    
end
    
    pl(i+1) = plot(act_area,abs(s_pa_c),'b.','markersize', 14);
    
    for i = 1:length(locs)
    plot(act_area(locs(i)), abs(s_pa_c(locs(i))),'gp','markersize', 10);
    hold on
    plot(act_area(locs(i)), abs(s_pa_c(locs(i))),'bo','markersize', 10);
    hold on
    plot(act_area(locs(i)), abs(s_pa_c(locs(i))),'r.','markersize', 20);
    hold on
    end
    
    pl(i+2) = plot(x_axis,ISO,'--r', 'MarkerSize',3, 'LineWidth',2);
    
title('Method 1B, SPACs compared with PPAC and ISO curve (ACTUAL AREA)')
axis([ 0 max(max(m1ba)) 0 max(max(max(m1bsp)))])
    xlabel('Area [m^2]')
    ylabel('Pressure [MPa]')
    legendInfo{length(locs)+1} = 'PPA values';
    legendInfo{length(locs)+2} = 'ISO Curve';
    legend(pl,legendInfo)
    hold off

print -dpng FIGURES\NCFORC_F22_M1B_SPACs_CW_PPAC_AND_ISO_ACTUAL_AREA.png -r600
%%
choose_line = zeros(ant_max,length(locs));
sxs = zeros(length(locs),1);
sys = zeros(length(locs),1);

for i=1:length(locs)
for s=1:ant_max
        
choose_line(s,i) = sum(M1B.spac(s,:,i));
end
line_val = min(choose_line(:,i));
[sxs(i) sys(i)] = ind2sub(size(choose_line),find(choose_line==line_val));
end

figure(23)
cd('FUNCTIONS')
for i = 1:length(locs)
subplot_tight(ceil(sqrt((length(locs)/2))),...
    ceil(sqrt((length(locs)/2))),i, .025)
set(figure(23),'Units','Normalized','OuterPosition',[0 0 1 1]) 
pos=get(gca,'pos');
set(gca,'pos',[pos(1) pos(2) pos(3) pos(4)*0.95]);
pos=get(gca,'pos');
contourf(y_axis,z_axis,ar_con1b(:,:,sxs(i),i))
colorbar;
legend(num2str(locs(i)))
hc=colorbar('location','eastoutside','position',...
    [pos(1) pos(2)+pos(4) pos(3), 0.01]);
set(hc,'xaxisloc','top');
axis off
set(gca, 'color', [1 1 1])
set(gcf, 'color', [1 1 1])
end
hold off
cd('../')

    
print -dpng FIGURES\NCFORC_F23_M1B_CONTROL_AREA.png -r600

%% ------------------------------------------------------------------------
% Method 2,SPAC compared with PPAC and ISO Curve (ACTUAL AREA)
%--------------------------------------------------------------------------
figure(24)
set(gcf,'color','w');
box on
clear legendInfo
clear pl
cd('FUNCTIONS')
colorM = distinguishable_colors(length(locs));
cd('../')

for i = 1:length(locs)
    
    m2a(i,:) = M2.SA(i,:);
    m2a(m2a == 0) = NaN;
    hold on
 
    p1 = colorM(i,1);
    p2 = colorM(i,2);
    p3 = colorM(i,3);
    
    m2sp(i,:) = abs(M2.SP(i,:))*10^-6;
    m2sp(m2sp == 0) = NaN;

    pl(i) = plot(m2a(i,:),m2sp(i,:),'Color', [p1 p2 p3],...
        'LineStyle', '-', 'LineWidth',2);
    legendInfo{i} = ['TS = ' num2str(locs(i))];
    
end
    s_act_area = (act_area);
    pl(i+1) = plot(s_act_area,abs(s_pa_c),'b.', 'LineWidth',2,...
    'markersize', 14);

    for i = 1:length(locs)
    plot(act_area(locs(i)), abs(s_pa_c(locs(i))),'gp','markersize', 10);
    hold on
    plot(act_area(locs(i)), abs(s_pa_c(locs(i))),'bo','markersize', 10);
    hold on
    plot(act_area(locs(i)), abs(s_pa_c(locs(i))),'r.','markersize', 20);
    hold on
    end

     pl(i+2) = plot(x_axis,ISO,'--r', 'MarkerSize',3, 'LineWidth',2);
    
    title('Method 2, SPACs compared with PPAC and ISO curve (ACTUAL AREA)')
    axis([ 0 max(max(m2a)) 0 max(max(m2sp))])
    xlabel('Area [m^2]')
    ylabel('Pressure [MPa]')
    legendInfo{length(locs)+1} = 'PPA values';
    legendInfo{length(locs)+2} = 'ISO Curve';
    legend(pl,legendInfo)
    hold off
    
print -dpng FIGURES\NCFORC_F24_M2_SPACs_CW_PPAC_AND_ISO_ACTUAL_AREA.png -r600
%%

figure(25)
cd('FUNCTIONS')
for i = 1:length(locs)
subplot_tight(ceil(sqrt((length(locs)/2))),...
    ceil(sqrt((length(locs)/2))),i, .025)
set(figure(25),'Units','Normalized','OuterPosition',[0 0 1 1]) 
pos=get(gca,'pos');
set(gca,'pos',[pos(1) pos(2) pos(3) pos(4)*0.95]);
pos=get(gca,'pos');
contourf(y_axis,z_axis,ar_con2(:,:,i))
colorbar;
legend(num2str(locs(i)))
hc=colorbar('location','eastoutside','position',...
    [pos(1) pos(2)+pos(4) pos(3), 0.01]);
set(hc,'xaxisloc','top');
axis off
set(gca, 'color', [1 1 1])
set(gcf, 'color', [1 1 1])
end
hold off
cd('../')

    
print -dpng FIGURES\NCFORC_F25_M2_CONTROL_AREA.png -r600

%% ------------------------------------------------------------------------
% Method 3,SPAC compared with PPAC and ISO Curve (ACTUAL AREA)
%--------------------------------------------------------------------------
figure(26)
set(gcf,'color','w');
box on
clear legendInfo
clear pl
cd('FUNCTIONS')
colorM = distinguishable_colors(length(locs));
cd('../')

for i = 1:length(locs)
    
    m3a(i,:) = M3.SA(i,:);
    m3a(m3a == 0) = NaN;
    hold on
 
    p1 = colorM(i,1);
    p2 = colorM(i,2);
    p3 = colorM(i,3);
    
    m3sp(i,:) = abs(M3.SP(i,:))*10^-6;
    m3sp(m3sp == 0) = NaN;

    pl(i) = plot(m3a(i,:),m3sp(i,:),'Color',...
        [p1 p2 p3], 'LineStyle', '-', 'LineWidth',2);
    legendInfo{i} = ['TS = ' num2str(locs(i))];
    
end
    s_act_area = (act_area);
    pl(i+1) = plot(s_act_area,abs(s_pa_c),'b.', 'LineWidth',2,...
    'markersize', 14);

    for i = 1:length(locs)
    plot(act_area(locs(i)), abs(s_pa_c(locs(i))),'gp','markersize', 10);
    hold on
    plot(act_area(locs(i)), abs(s_pa_c(locs(i))),'bo','markersize', 10);
    hold on
    plot(act_area(locs(i)), abs(s_pa_c(locs(i))),'r.','markersize', 20);
    hold on
    end

     pl(i+2) = plot(x_axis,ISO,'--r', 'MarkerSize',3, 'LineWidth',2);
    
title('Method 3, SPACs compared with PPAC and ISO curve (ACTUAL AREA)')
axis([ 0 max(max(m3a)) 0 max(max(m3sp))])
    xlabel('Area [m^2]')
    ylabel('Pressure [MPa]')
    legendInfo{length(locs)+1} = 'PPA values';
    legendInfo{length(locs)+2} = 'ISO Curve';
    legend(pl,legendInfo)
    hold off
    
print -dpng FIGURES\NCFORC_F26_M3_SPACs_CW_PPAC_AND_ISO_ACTUAL_AREA.png -r600
%%

figure(27)
cd('FUNCTIONS')
for i = 1:length(locs)
subplot_tight(ceil(sqrt((length(locs)/2))),...
    ceil(sqrt((length(locs)/2))),i, .025)
set(figure(27),'Units','Normalized','OuterPosition',[0 0 1 1]) 
pos=get(gca,'pos');
set(gca,'pos',[pos(1) pos(2) pos(3) pos(4)*0.95]);
pos=get(gca,'pos');
contourf(y_axis,z_axis,ar_con3(:,:,i))
colorbar;
legend(num2str(locs(i)))
hc=colorbar('location','eastoutside','position',...
    [pos(1) pos(2)+pos(4) pos(3), 0.01]);
set(hc,'xaxisloc','top');
axis off
set(gca, 'color', [1 1 1])
set(gcf, 'color', [1 1 1])
end
hold off
cd('../')

  
print -dpng FIGURES\NCFORC_F27_M3_CONTROL_AREA.png -r600

%% ------------------------------------------------------------------------
% Method 4,SPAC compared with PPAC and ISO Curve (ACTUAL AREA)
%--------------------------------------------------------------------------

M5t(:,2,:) = abs(M5t(:,2,:)).*10^-6;

figure(28)
set(gcf,'color','w');
box on
clear legendInfo
clear pl
cd('FUNCTIONS')
colorM = distinguishable_colors(length(locs));
cd('../')

for i = 1:length(locs)
	clear M5t_pks M5t_locs M5_pks M5_locs M5tpks M5tlocs 
      
    M5t_pks(:,1) = M5t(:,2,i);
    M5t_locs(:,1) = M5t(:,1,i);
                
	[M5_pks,M5_locs]=findpeaks(M5t(:,2,i),'minpeakdistance',10);
                
                
    M5t_pks(M5_locs(1):M5_locs(end)) = 0;
    M5t_pks(M5t_pks == 0) = NaN;
                
    M5plot(:,1) = M5t_locs;
    M5plot(:,2) = M5t_pks;
                
    for j = 1:length(M5_pks)
        M5plot(M5_locs(j),2) = M5_pks(j);
    end    
               
    M5p = M5plot(0== sum(isnan(M5plot), 2), :);

    p1 = colorM(i,1);
    p2 = colorM(i,2);
    p3 = colorM(i,3);
   
    pl(i) = plot(M5p(:,1),M5p(:,2),'Color', [p1 p2 p3],...
        'LineStyle', '-', 'LineWidth',2);
    legendInfo{i} = ['TS = ' num2str(locs(i))];
    hold on
end

    s_act_area = (act_area);
    pl(i+1) = plot(s_act_area,abs(s_pa_c),'b.', 'LineWidth',2,...
    'markersize', 14);

    for i = 1:length(locs)
    plot(act_area(locs(i)), abs(s_pa_c(locs(i))),'gp','markersize', 10);
    hold on
    plot(act_area(locs(i)), abs(s_pa_c(locs(i))),'bo','markersize', 10);
    hold on
    plot(act_area(locs(i)), abs(s_pa_c(locs(i))),'r.','markersize', 20);
    hold on
    end

     pl(i+2) = plot(x_axis,ISO,'--r', 'MarkerSize',3, 'LineWidth',2);

    title('Method 3, SPACs compared with PPAC and ISO curve (ACTUAL AREA)')
    axis([ 0 max(max(M5p(:,1))) 0 max(max(M5p(:,2)))])
    xlabel('Area [m^2]')
    ylabel('Pressure [MPa]')
    legendInfo{length(locs)+1} = 'PPA values';
    legendInfo{length(locs)+2} = 'ISO Curve';
    legend(pl,legendInfo)
    hold off

print -dpng FIGURES\NCFORC_F28_M4_SPACs_CW_PPAC_AND_ISO_ACTUAL_AREA.png -r600
%%

figure(29)
cd('FUNCTIONS')
for i = 1:length(locs)
subplot_tight(ceil(sqrt((length(locs)/2))),...
    ceil(sqrt((length(locs)/2))),i, .025)
set(figure(29),'Units','Normalized','OuterPosition',[0 0 1 1]) 
pos=get(gca,'pos');
set(gca,'pos',[pos(1) pos(2) pos(3) pos(4)*0.95]);
pos=get(gca,'pos');
contourf(y_axis,z_axis,ar_con4_all(:,:,i))
colorbar;
legend(num2str(locs(i)))
hc=colorbar('location','eastoutside','position',...
    [pos(1) pos(2)+pos(4) pos(3), 0.01]);
set(hc,'xaxisloc','top');
axis off
set(gca, 'color', [1 1 1])
set(gcf, 'color', [1 1 1])
end
hold off
cd('../')

    
print -dpng FIGURES\NCFORC_F29_M4_SPACs_CONTROL_AREA.png -r600

%% ------------------------------------------------------------------------
% PART 4: CONTOUR PLOTS
%--------------------------------------------------------------------------

figure(10)
cd('FUNCTIONS')
for i = 1:length(locs)
PTS(:,:,i) = dyna(:,:,5,locs(i))*10^-6;
subplot_tight(ceil(sqrt((length(locs)/2))),...
    ceil(sqrt((length(locs)/2))),i, .025)
set(figure(10),'Units','Normalized','OuterPosition',[0 0 1 1]) 
pos=get(gca,'pos');
set(gca,'pos',[pos(1) pos(2) pos(3) pos(4)*0.95]);
pos=get(gca,'pos');
contourf(y_axis,z_axis,PTS(:,:,i))
colorbar;
legend(num2str(locs(i)))
hc=colorbar('location','eastoutside','position',...
    [pos(1) pos(2)+pos(4) pos(3), 0.01]);
set(hc,'xaxisloc','top');
axis off
set(gca, 'color', [1 1 1])
set(gcf, 'color', [1 1 1])
end
hold off
cd('../')


print('-dpng','FIGURES\NCFORC_F10_CONTOUR_PLOT_MANY_FORCE_PEAKS.png'...
    ,'-r1200')

%%
%CONTOUR PLOT startpoint:
%--------------------------------------------------------------------------
figure(11)
contourf(y_axis,z_axis,PTS(:,:,1))
colorbar;
title({'TIMESTEP NUMBER', num2str(locs(1))}) 
legend('MPA')
xlabel('[m]')
ylabel('[m]')
set(gca, 'color', [1 1 1])
set(gcf, 'color', [1 1 1])
hold off
%%
print -dpng FIGURES\NCFORC_F11_CONTOUR_PLOT_FIRST_PEAK.png -r600
%%
%CONTOUR PLOT MedianPlot:
%--------------------------------------------------------------------------
figure(12)
contourf(y_axis,z_axis,PTS(:,:,ceil(length(locs)/2)))
colorbar;
title({'TIMESTEP NUMBER', num2str(locs(ceil(length(locs)/2)))}) 
legend('MPA')
xlabel('[m]')
ylabel('[m]')
set(gca, 'color', [1 1 1])
set(gcf, 'color', [1 1 1])
hold off

print -dpng FIGURES\NCFORC_F12_CONTOUR_PLOT_MEDIAN_PEAK.png -r600
%%
%CONTOUR PLOT LastPlot:
%--------------------------------------------------------------------------
figure(13)
contourf(y_axis,z_axis,PTS(:,:,length(locs)))
colorbar;
title({'TIMESTEP NUMBER', num2str(locs(length(locs)))}) 
legend('MPA')
xlabel('[m]')
ylabel('[m]')
set(gca, 'color', [1 1 1])
set(gcf, 'color', [1 1 1])
hold off
%%
print -dpng FIGURES\NCFORC_F13_CONTOUR_PLOT_LAST_PEAK.png -r600



%% ------------------------------------------------------------------------
%   PROCESS PRESSURE-AREA CURVES
%   Compared with ISO curve and 3[m^2] Pond Inlet
%--------------------------------------------------------------------------

Kierk = load('IMPORTS/K_implot.mat','pacall');

cd('FUNCTIONS')
plotsam
cd('../')

figure(30)
title('Process prssure-area curve compared with Pond Inlet and ISO')
plot(asum_cont_area, abs(p_pa_c),'red',...
    asum_cont_area,abs(Kierk.pacall(1:200)),'b-',...
    x_axis,ISO,'m',...
    cur1(:,1), cur1(:,2),'g-',cur2(:,1),cur2(:,2),'g-',...
    cur3(:,1),cur3(:,2),'g-',cur4(:,1),cur4(:,2),'g-')
axis([ 0 6 0 40])
set(gcf,'color','w');
legend('Process pressure area curve','Kierkgaard','ISO','Pond Inlet')
hold off

print -dpng FIGURES\NCFORC_F30_CW_PONDINLET_ISO.png -r600
%%
% SAVING WORKPLACE!!!!
 savefile =  'VARIABLES/WP_NCFORC.mat';
 save(savefile)

