%**************************************************************************
%               Post-Processing LS-DYNA Results SCRIPT
%**************************************************************************
%                   Post-processing of the NCFORC-FILE
%**************************************************************************
%      Process and Spatial pressure-area Curves calculation SCRIPT
% PART 1: Process pressure-area curve calculations
% PART 2: Spatial pressure-area curves calculations
%**************************************************************************
%------------------------------->>        DEVELOPED BY: SIMEN BHLERENGEN
%**************************************************************************
% PART 1: Process presssure-area curve CALCULATION:
%**************************************************************************
indent = zeros(NR_TS,1);
force = zeros(NR_TS,1);
asum_cont_area = zeros(NR_TS,1);

for t=1:NR_TS

% FORCE OBTAINED:
%--------------------------------------------------------------------------
% Force in y-direcion (2D): (Activated)
force(t)= abs(sum(sum(dyna(:,:,2,t))));

% Resultant force: (Deactivated)
% force(t)= sqrt((sum(sum(dyna(:,:,2,t))))^2+...
%           (sum(sum(dyna(:,:,3,t))))^2+(sum(sum(dyna(:,:,4,t))))^2);


% Analytical , calculation, based on SAGITTA (geometry) relationship:
%--------------------------------------------------------------------------
% Finding the SAGITTA length (S):
if sum(sum(dyna(:,:,2,t))) == 0
ini_s = v*TIME(t);              % inital length (before impact)
start_impact = t+1;             % impact timestep
else
indent(t) = v*TIME(t);          % indentation length

% Radius of the circular contact-area (h):
seg_r = sqrt(2*(indent(t)-ini_s)*r-(indent(t)-ini_s)^2);

% Analytical contact area (based on SAGITTA relation):
asum_cont_area(t) = pi*seg_r^2;
end
end
%%
% Nonimal area vs Actual area:
%--------------------------------------------------------------------------
act_area = zeros(NR_TS,1);
area_ratio = zeros(NR_TS,1);
for i = 1:NR_TS
act_area(i) = sum(sum(dyna(:,:,2,i)~=0))*(Meshsize)^2;
area_ratio(i)  = act_area(i)/asum_cont_area(i);
end

%SAVE VARIABLES:
%--------------------------------------------------------------------------
savefile = 'VARIABLES/p_pa_c.mat';
p_pa_c = (10^(-6)*force)./asum_cont_area;
save(savefile, 'p_pa_c');

savefile = 'VARIABLES/s_pa_c.mat';
s_pa_c= (10^(-6)*force)./act_area;
save(savefile, 's_pa_c');

savefile = 'VARIABLES/time.mat';
save(savefile, 'TIME');

savefile = 'VARIABLES/indent.mat';
save(savefile, 'indent');

MN_F = force*10^-6;
savefile = 'VARIABLES/MN_F.mat';
save(savefile, 'MN_F');

savefile = 'VARIABLES/ppac.mat';
ppac = smooth(asum_cont_area,abs(p_pa_c),0.05,'loess');
save(savefile, 'ppac');

PRINT_CALC = sprintf('Forces, pressures and areas calculated');
disp(PRINT_CALC)

%%

%**************************************************************************
% PART II)   Spartial pressure-area curves CALCULATION:
%**************************************************************************
% CHOOSE TIME-STEPS:    (INPUT)
%--------------------------------------------------------------------------
% CHOSEN/SPECIFIC TIME-STEPS: (activeted)
disp('TIME-STEPS:')
locs = [11 21 41 61 81 111 141 171 200]

% TIME-STEP ON FORCEPEAKS: (deactivated)
%[pks,locs]=findpeaks(force,'minpeakdistance',30,'NPEAKS',9);

% Choose accuracy how many elements that are summed together:
% NB!! SHOULD SET TO 1, and 1 is default!
OppdTall = 1;
% Number of Maximum Analysed:
% NB, higher increase the matlab code significantly!
% 5 is default, and are know to give acceptable results.
ant_max = 5;
%Choose accuracy or number of points on x-axis for method number 3:
NR_CON = 40;
%--------------------------------------------------------------------------

STP = locs;

%Skriver ut oppdelingen:
OppdW = floor(NR_W/OppdTall);   % rectangle
OppdH = floor(NR_H/OppdTall);   % rectangle
Oppd = floor((OppdH+OppdW)/2);  % squares

elem = zeros(OppdH,OppdW,length(locs));
start_impact_area_values = zeros(OppdH,OppdW);
sy = zeros(ant_max,length(locs));
sx = zeros(ant_max,length(locs));

% SPLITT TOTAL AREA INTO SUB-AREAS:  
for ste = 1:length(locs)
    n1= -OppdTall+1;
    n2= 0;
for x = 1:Oppd
	n1 = n1+OppdTall;
    n2 = n2+OppdTall;
    m1 = -OppdTall+1;
    m2 = 0;
 
 for c = 1:Oppd
    m1 = m1+OppdTall;
    m2 = m2+OppdTall;

elem(c,x,ste) = (sum(sum(dyna(m1:m2,n1:n2,2,STP(ste)))));
start_impact_area_values(c,x) = sum(sum(dyna(m1:m2,n1:n2,5,start_impact)));
 end
end
end

% FINDING MAXIMUM PRESSURES and OBTAIN ACTUAL AREA:
act_ar_sum = zeros(length(locs),1);
act_ar_sum_k = zeros(length(locs),1);
act_ar_sum_r = zeros(length(locs),1);

for ste = 1:length(locs)

act_ar=elem(:,:,ste);
act_ar(act_ar == 0) = NaN;
act_ar = ~isnan(act_ar);
act_ar_sum(ste,1) = sum(sum(act_ar(:,:)));
act_ar_r = sum(act_ar,2);
act_ar_r(act_ar_r == 0) = NaN;
act_ar_r = ~isnan(act_ar_r);
act_ar_k = sum(act_ar,1);
act_ar_k(act_ar_k == 0) = NaN;
act_ar_k = ~isnan(act_ar_k);
act_ar_sum_r(ste,1) = sum(act_ar_r);
act_ar_sum_k(ste,1) = sum(act_ar_k);

    
Arraycopy = elem(:,:,ste);
Array_dup = elem(:,:,ste);

for j = 1:ant_max
   [num, Index(j)] = min(Arraycopy(:));
   Arraycopy(Index(j)) = 0;
   maximumValues = Array_dup(Index);
   maxVal = find(Array_dup==maximumValues(j));
   [sx(j,ste) sy(j,ste)] = ind2sub(size(Array_dup),maxVal(1));
end
end
%%


%--------------------------------------------------------------------------
% CALCULATION of METHOD 1A
% Expand-Maxima Method (rectangular shape areas):
%--------------------------------------------------------------------------
PRINT_CALC = sprintf('Calculation of method 1A:');
disp(PRINT_CALC)

ar_con1a = zeros(OppdW,OppdH,ant_max,length(locs));

for ste = 1:length(locs)    % TIME-STEPS
for sa = 1:ant_max          % High presssure zones
x=sx(sa,ste);
y=sy(sa,ste);
copy_elem=elem(:,:,ste);
act_ar1a = act_ar_sum_r+act_ar_sum_k-1;

sum_area = 0;
sum_pressure = 0;
k=0;
clear rp kp rad_max rad_min kol_min kol_max
runde = 0;

while sum(sum(copy_elem(:,:))) ~= Oppd*Oppd*0
    k = 1+k;
    rp(k) = x(1);
    kp(k) = y(1);

    rad_max = max(rp(:));
    rad_min = min(rp(:));
    kol_max = max(kp(:));
    kol_min = min(kp(:));
    rad = rad_min:rad_max;
    kol = kol_min:kol_max;

% Element with zeros pressure    
trek_zero = sum(sum(elem(rad_min:rad_max,kol_min:kol_max,ste)==0));
% Actual area for each TIME-STEP and for each area expansion:
sum_area = (rad_max-rad_min+1)*(kol_max-kol_min+1)*...
    (Meshsize*OppdTall)^2-(Meshsize*OppdTall)^2*trek_zero;
M1A.SA(k,ste) = sum_area;

% Pressure for each TIME-STEP and for each area expansion:
    sum_pressure = sum(sum(elem(rad_min:rad_max,kol_min:kol_max,ste)));
    M1A.spac(sa,k,ste) = sum_pressure/M1A.SA(k,ste);
    M1A.SP(k,ste) = min(M1A.spac(:,k,ste));

% Creating COLOUR LEVELS for the contour-plot in script: PLOT.m
    if k/act_ar1a <= 0.005
        ar_con1a(x,y,sa,ste) = 10;
    elseif k/act_ar1a <= 0.10
        ar_con1a(x,y,sa,ste) = 9;
    elseif k/act_ar1a <= 0.20
        ar_con1a(x,y,sa,ste) = 8;
    elseif k/act_ar1a <= 0.30
        ar_con1a(x,y,sa,ste) = 7;
    elseif k/act_ar1a <= 0.40
        ar_con1a(x,y,sa,ste) = 6;
    elseif k/act_ar1a <= 0.50
        ar_con1a(x,y,sa,ste) = 5;
    elseif k/act_ar1a <= 0.60
        ar_con1a(x,y,sa,ste) = 4;        
    elseif k/act_ar1a <= 0.70
        ar_con1a(x,y,sa,ste) = 3;
    elseif k/act_ar1a <= 0.80
        ar_con1a(x,y,sa,ste) = 2;
    elseif k/act_ar1a <= 0.90
        ar_con1a(x,y,sa,ste) = 1;
    elseif k/act_ar1a <= 0.99
        ar_con1a(x,y,sa,ste) = 0;        
    else
    end

    copy_elem(rad_min:rad_max,kol_min:kol_max) = 0;
    
    right = sum(copy_elem(rad_min:rad_max,kol_max+1)/...
        (Meshsize*(rad_max-rad_min)));
    left = sum(copy_elem(rad_min:rad_max,kol_min-1)/...
        (Meshsize*(rad_max-rad_min)));
    up = sum(copy_elem(rad_min-1,kol_min:kol_max)/...
        (Meshsize*(kol_max-kol_min)));
    down = sum(copy_elem(rad_max+1,kol_min:kol_max)/...
        (Meshsize*(kol_max-kol_min)));
    
    mat_check = [right,left,up,down];
    pos_check = find(mat_check==min(min(mat_check)));

    if pos_check == 1
        x = rad;
        y = kol_max + 1;
    elseif pos_check == 2
        x = rad;
        y = kol_min - 1;
    elseif pos_check == 3
        x = rad_min - 1;
        y = kol;
    elseif pos_check == 4
        x = rad_max + 1;
        y = kol;
    else
        
        runde = runde + 1;
        if runde == 5
            runde = 1;
        else 
        end
        
        if runde == 1
            x = rad;
            y = kol_max + 1;
        elseif runde == 2
            x = rad;
            y = kol_min - 1;
        elseif runde == 3
            x = rad_min - 1;
            y = kol;
        elseif runde == 4
            x = rad_max + 1;
            y = kol;
        else
        end
    end
end
end
end
disp('Method 1A DONE')


%% ------------------------------------------------------------------------
% CALCULATION of METHOD 1B
% Expand-Maxima Method (rectangular shape areas):
%--------------------------------------------------------------------------
PRINT_CALC = sprintf('Calculation of method 1B:');
disp(PRINT_CALC)

ar_con1b = zeros(OppdW,OppdH,ant_max,length(locs));

for ste = 1:length(locs)
    for sa = 1:ant_max
        x=sx(sa,ste);
        y=sy(sa,ste);
        copy_elem=elem(:,:,ste);
        sum_area = 0;
        sum_pressure = 0;
        k=0;
        clear rp kp

while sum(sum(copy_elem(:,:))) ~= Oppd*Oppd*0 
    k = 1+k;
    
% Actual area for each TIME-STEP and for each area expansion:
    sum_area = sum_area + (Meshsize*OppdTall)^2;
    M1B.SA(k,ste) = sum_area;
% Pressure for each TIME-STEP and for each area expansion:
    sum_pressure = sum_pressure + elem(x,y,ste);
    M1B.spac(sa,k,ste) = sum_pressure/M1B.SA(k,ste);
    M1B.SP(k,ste) = min(M1B.spac(:,k,ste));
    copy_elem(x,y) = 0;

% Creating COLOUR LEVELS for the contour-plot in script: PLOT.m
    if k/act_ar_sum(ste,1) <= 0.005
        ar_con1b(x,y,sa,ste) = 10;
    elseif k/act_ar_sum(ste,1) <= 0.01
        ar_con1b(x,y,sa,ste) = 9;
    elseif k/act_ar_sum(ste,1) <= 0.05
        ar_con1b(x,y,sa,ste) = 8;
    elseif k/act_ar_sum(ste,1) <= 0.10
        ar_con1b(x,y,sa,ste) = 7;
    elseif k/act_ar_sum(ste,1) <= 0.20
        ar_con1b(x,y,sa,ste) = 6;
    elseif k/act_ar_sum(ste,1) <= 0.30
        ar_con1b(x,y,sa,ste) = 5;
    elseif k/act_ar_sum(ste,1) <= 0.40
        ar_con1b(x,y,sa,ste) = 4;
    elseif k/act_ar_sum(ste,1) <= 0.50
        ar_con1b(x,y,sa,ste) = 3;
    elseif k/act_ar_sum(ste,1) <= 0.60
        ar_con1b(x,y,sa,ste) = 2;
    elseif k/act_ar_sum(ste,1) <= 0.80
        ar_con1b(x,y,sa,ste) = 1;        
    elseif k/act_ar_sum(ste,1) <= 0.95
        ar_con1b(x,y,sa,ste) = 0;
    else
    end
        
    rp(k) = x;
    kp(k) = y;
   
	for i=1:k
        
     %CHECKS left, right, up and down elements:
     check1 = min((copy_elem(rp(i)-1,kp(i))),(copy_elem(rp(i),kp(i)-1)));
     check2 = min((copy_elem(rp(i)+1,kp(i))),(copy_elem(rp(i),kp(i)+1)));
     check11 = min(check1,check2);
        
%CHECKS DIAGONAL elements:
%check3 = min((copy_elem(rp(i)-1,kp(i)-1)),(copy_elem(rp(i)+1,kp(i)+1)));
%check4 = min((copy_elem(rp(i)-1,kp(i)+1)),(copy_elem(rp(i)+1,kp(i)-1)));
%check22 = min(check3,check4);
        
        next_HPA = min(check11);  %INCLUDE for diagonal search,(check22)
        HPA(i) = next_HPA;
	end
   
	HPAlist = min(HPA(:));
   
	if HPAlist == 0
	search = 1;
    while search<=20 && HPAlist == 0 && min(rp)-search >= 2 ...
           && min(kp)-search >= 2 ...
           && max(rp)+search <= length(elem(:,:,ste))-1 ...
           && max(kp)+search <= length(elem(:,:,ste))-1
       
       search = search +1;
       for i=1:k
            %CHECKS left, right, up and down elements:
            check1 = min((copy_elem(rp(i)-search,kp(i))),...
                (copy_elem(rp(i),kp(i)-search)));
            check2 = min((copy_elem(rp(i)+search,kp(i))),...
                (copy_elem(rp(i),kp(i)+search)));
            check11 = min(check1,check2);
   
%CHECKS DIAGONAL elements:
%check3 = min((copy_elem(rp(i)-1,kp(i)-1)),(copy_elem(rp(i)+1,kp(i)+1)));
%check4 = min((copy_elem(rp(i)-1,kp(i)+1)),(copy_elem(rp(i)+1,kp(i)-1)));
%check22 = min(check3,check4);

        next_HPA = min(check11); %INCLUDE for diagonal search,(check22)
        HPA(i) = next_HPA;
       end
	HPAlist = min(HPA(:));
    end
    else
    end
	[x y] = ind2sub(size(copy_elem),find(copy_elem==HPAlist));    
	x=x(1);
	y=y(1);
end
end
end
disp('Method 1B DONE')



%% ------------------------------------------------------------------------
% EXPANDING AREA PROCESS ITERATION: NUMBER 2
% Box-Averaging Method
%--------------------------------------------------------------------------
PRINT_CALC = sprintf('Calculation of method 2:');
disp(PRINT_CALC)

ar_con2 = zeros(OppdW,OppdH,length(locs));

for ste = 1:length(locs)
    
% Starting/first sub-area, before expanding uniformaly to each side!
% Chosen to be at first impact position.
    max_siav = min(min(start_impact_area_values(:,:)));
    [x y] = ind2sub(size(start_impact_area_values),...
        find(start_impact_area_values==max_siav));

    m1 = x;
    n1 = y;
    m2 = x;
    n2 = y;

    sum_pressure = 0;
    sum_area = 0;
    k = 0;

    act_ar2 = min(act_ar_sum_r,act_ar_sum_k);

while length(elem(:,:,ste))> m2 && length(elem(:,:,ste))>n2...
        && 1<m1 && 1<n1
    
    k=k+1;
    m1 = m1-1;
    n1 = n1-1;
    m2 = m2+1;
    n2 = n2+1;

% Actual area for each TIME-STEP and for each area expansion:
    trek_zero = sum(sum(elem(m1:m2,n1:n2,ste)==0));
    M2.SA(ste,k) = ((m2-m1+1)*Meshsize*OppdTall)^2 -...
        (Meshsize*OppdTall)^2*trek_zero;
% Pressure for each TIME-STEP and for each area expansion:    
    M2.SP(ste,k) = sum(sum(elem(m1:m2,n1:n2,ste)))/ M2.SA(ste,k);

% Creating COLOUR LEVELS for the contour-plot in script: PLOT.m    
    if k/act_ar2(ste) <= 0.05
        ar_con2(m1:m2,n1:n2,ste) = ar_con2(m1:m2,n1:n2,ste)+ 1;
    elseif k/act_ar2(ste) <= 0.15
        ar_con2(m1:m2,n1:n2,ste) = ar_con2(m1:m2,n1:n2,ste)+ 1;
    elseif k/act_ar2(ste) <= 0.30
        ar_con2(m1:m2,n1:n2,ste) = ar_con2(m1:m2,n1:n2,ste)+ 1;
    elseif k/act_ar2(ste) <= 0.50
        ar_con2(m1:m2,n1:n2,ste) = ar_con2(m1:m2,n1:n2,ste)+ 1;
    elseif k/act_ar2(ste) <= 0.80
        ar_con2(m1:m2,n1:n2,ste) = ar_con2(m1:m2,n1:n2,ste)+ 1;
    else
    end
end
end
disp('Method 2 DONE')

%% ------------------------------------------------------------------------
% EXPANDING AREA PROCESS ITERATION: NUMBER 3
% Contour-Averaging Method
%--------------------------------------------------------------------------
PRINT_CALC = sprintf('Calculation of method 3:');
disp(PRINT_CALC)

ar_con3 = zeros(OppdW,OppdH,length(locs));

for ste = 1:length(locs)
c = 0;
list_elem = zeros(1,(length(elem(:,:,ste)))^2);

for k = 1:length(elem(:,:,ste))
    for h = 1:length(elem(:,:,ste))
        c = c+1;
        list_elem(c) = elem(k,h,ste);                
    end
end

sort_list_elem = sort(list_elem);
level_down = abs(sort_list_elem(1)):-abs(sort_list_elem(1)/NR_CON):0;
level_down(1) = level_down(1)-1;

if exist('M3') == 0
M3.SP = zeros(length(locs),NR_CON+1);
M3.SA = zeros(length(locs),NR_CON+1);
else
end

for i=1:NR_CON+1
    k = 1;
    sum1 = 0;

    while abs(sort_list_elem(k)) > level_down(i)        
% Actual area for each TIME-STEP and for each area expansion:
        M3.SA(ste,i) = (Meshsize*OppdTall)^2*k ;

        sum1 = sum1 + abs(sort_list_elem(k));
        M3.F(i) = sum1;

% Pressure for each TIME-STEP and for each area expansion:
        M3.SP(ste,i) = M3.F(i)/M3.SA(ste,i);
    
        k = k + 1;
    end
end
max_fo = min(min(elem(:,:,ste)));

for y=1:OppdH
    for x=1:OppdW

% Creating COLOUR LEVELS for the contour-plot in script: PLOT.m        
    if abs(elem(x,y,ste)/max_fo) <= 0  
        ar_con3(x,y,ste) = 0;  
    elseif abs(elem(x,y,ste)/max_fo) <= 0.001  
        ar_con3(x,y,ste) = 1;        
    elseif abs(elem(x,y,ste)/max_fo) <= 0.005  
        ar_con3(x,y,ste) = 2;
    elseif abs(elem(x,y,ste)/max_fo) <= 0.01
        ar_con3(x,y,ste) = 3;
    elseif abs(elem(x,y,ste)/max_fo) <= 0.10
        ar_con3(x,y,ste) = 4;
    elseif abs(elem(x,y,ste)/max_fo) <= 0.20    
        ar_con3(x,y,ste) = 5;
    elseif abs(elem(x,y,ste)/max_fo) <= 0.30
        ar_con3(x,y,ste) = 6;
    elseif abs(elem(x,y,ste)/max_fo) <= 0.40
        ar_con3(x,y,ste) = 7;
    elseif abs(elem(x,y,ste)/max_fo) <= 0.50
        ar_con3(x,y,ste) = 8;
    elseif abs(elem(x,y,ste)/max_fo) <= 0.70
        ar_con3(x,y,ste) = 9;
    elseif abs(elem(x,y,ste)/max_fo) <= 0.80
        ar_con3(x,y,ste) = 10;        
    else
    end
      
    end
end
end
disp('Method 3 DONE')

%% ------------------------------------------------------------------------
% EXPANDING AREA PROCESS ITERATION: NUMBER 4
% Iteration-Maxima Method
%--------------------------------------------------------------------------
PRINT_CALC = sprintf('Calculation of method 4:');
disp(PRINT_CALC)
 
Oppd_length = ceil(Oppd/3);
arsize = zeros(Oppd_length,1);
for i=1:Oppd_length
    arsize(i) = Oppd-3*i;
end
length_trek = (sum(arsize))*2;
area_length = Oppd^2-length_trek;


ar_con4_all = zeros(OppdH,OppdW,length(locs));
M5t = zeros(area_length,2,length(locs));

max_sub = zeros(area_length,1);
pressure_sub = zeros(area_length,1);
area_sub = zeros(area_length,1);
subyy = zeros(area_length,1);
subxx = zeros(area_length,1);
exrad = zeros(area_length,1);
exkol = zeros(area_length,1);
M4 = zeros(area_length,2);
M4sort = zeros(area_length,2);


for ste = 1:length(locs)

    calc_mat = zeros(OppdH,OppdW,area_length);
    
    ex_rad=0;
    ex_kol = 0;
    maxnu =0;
    ifcount=0;

for exd = 1:OppdH
   ex_rad = ex_rad + 1;
   
    while  ex_kol < Oppd && ex_kol/ex_rad < 3
        ex_kol = ex_kol + 1;
        maxnu = maxnu+1;
        rs=0;

        while rs <= (OppdH-ex_rad)
            rs = rs + 1;
            re = rs + ex_rad-1; 
            ks = 0;
            
           while ks <= (OppdW-ex_kol)
                ks = ks + 1;
                ke = ks + ex_kol-1;

                calc_mat(rs,ks,maxnu) = sum(sum(elem(rs:re,ks:ke,ste)));
           end
        end
        max_sub(maxnu) = min(min(calc_mat(:,:,maxnu)));
        [suby subx] = ind2sub(size(calc_mat(:,:,maxnu)),...
            find(calc_mat(:,:,maxnu)==max_sub(maxnu)));
                
%Zero pressure elements:
trek_zero = sum(sum(elem(suby(ceil(length(suby)/2)):...
(suby(ceil(length(suby)/2))+ex_rad-1),...
subx(ceil(length(subx)/2)):(subx(ceil(length(subx)/2))+ex_kol-1),ste)==0));
% Actual area for each sub-area:
area_sub(maxnu) = ex_rad*ex_kol*(Meshsize*OppdTall)^2 -...
    (Meshsize*OppdTall)^2*trek_zero;
% Pressure for each sub-area:
pressure_sub(maxnu) = max_sub(maxnu)/area_sub(maxnu);
                
    subyy(maxnu) = suby(ceil(length(subx)/2));
    subxx(maxnu) = subx(ceil(length(subx)/2));
    exrad(maxnu)=ex_rad;
    exkol(maxnu)=ex_kol;
    end
            if mod(ex_rad,3) == 0 && ex_rad > 0
                ifcount = ifcount + 1;
                ex_kol = ifcount;
            else
                ex_kol = ifcount;
            end
end

	M4(:,1) = area_sub(:);
    M4(:,2) = pressure_sub(:);
	M4sort(:,:) = sortrows(M4(:,:),[1 2]);
	M5t(:,:,ste) = M4sort(:,:);
           
    M5maxar = zeros(area_length,2);
    M5maxar(:,:) = M5t(:,:,ste);
    M5maxar(:,2) = abs(M5maxar(:,2))*10^-6;
    [M5_pks,M5_locs]=findpeaks(M5maxar(:,2),'minpeakdistance',10);

% Creating COLOUR LEVELS for the contour-plot in script: PLOT.m 
ar_con4_all(subyy(area_length):(subyy(area_length)+exrad(area_length)-1)...
  ,subxx(area_length):(subxx(area_length)+exkol(area_length)-1),ste) = 0;
ar_con4_all(subyy(ceil(M5_locs(end)*0.8)):(subyy(ceil(M5_locs(end)*0.8))...
  +exrad(ceil(M5_locs(end)*0.8))-1),subxx(ceil(M5_locs(end)*0.8)):...
  (subxx(ceil(M5_locs(end)*0.8))+exkol(ceil(M5_locs(end)*0.8))-1),ste) = 1;
ar_con4_all(subyy(ceil(M5_locs(end)*0.6)):(subyy(ceil(M5_locs(end)*0.6))...
  +exrad(ceil(M5_locs(end)*0.6))-1),subxx(ceil(M5_locs(end)*0.6)):...
  (subxx(ceil(M5_locs(end)*0.6))+exkol(ceil(M5_locs(end)*0.6))-1),ste) = 2;
ar_con4_all(subyy(ceil(M5_locs(end)*0.5)):(subyy(ceil(M5_locs(end)*0.5))...
  +exrad(ceil(M5_locs(end)*0.5))-1),subxx(ceil(M5_locs(end)*0.5)):...
  (subxx(ceil(M5_locs(end)*0.5))+exkol(ceil(M5_locs(end)*0.5))-1),ste) = 3;
ar_con4_all(subyy(ceil(M5_locs(end)*0.4)):(subyy(ceil(M5_locs(end)*0.4))...
 +exrad(ceil(M5_locs(end)*0.4))-1),subxx(ceil(M5_locs(end)*0.4)):...
 (subxx(ceil(M5_locs(end)*0.4))+exkol(ceil(M5_locs(end)*0.4))-1),ste) = 4;
ar_con4_all(subyy(ceil(M5_locs(end)*0.3)):(subyy(ceil(M5_locs(end)*0.3))...
  +exrad(ceil(M5_locs(end)*0.3))-1),subxx(ceil(M5_locs(end)*0.3)):...
  (subxx(ceil(M5_locs(end)*0.3))+exkol(ceil(M5_locs(end)*0.3))-1),ste) = 5;
ar_con4_all(subyy(ceil(M5_locs(end)*0.2)):(subyy(ceil(M5_locs(end)*0.2))...
  +exrad(ceil(M5_locs(end)*0.2))-1),subxx(ceil(M5_locs(end)*0.2)):...
  (subxx(ceil(M5_locs(end)*0.2))+exkol(ceil(M5_locs(end)*0.2))-1),ste) = 6;
ar_con4_all(subyy(ceil(M5_locs(end)*0.1)):(subyy(ceil(M5_locs(end)*0.1))...
  +exrad(ceil(M5_locs(end)*0.1))-1),subxx(ceil(M5_locs(end)*0.1)):...
  (subxx(ceil(M5_locs(end)*0.1))+exkol(ceil(M5_locs(end)*0.1))-1),ste) = 7;
ar_con4_all(subyy(ceil(M5_locs(end)*0.05)):...
    (subyy(ceil(M5_locs(end)*0.05))+exrad(ceil(M5_locs(end)*0.05))-1),...
    subxx(ceil(M5_locs(end)*0.05)):(subxx(ceil(M5_locs(end)*0.05))+...
    exkol(ceil(M5_locs(end)*0.05))-1),ste) = 8;
ar_con4_all(subyy(ceil(M5_locs(end)*0.01)):...
    (subyy(ceil(M5_locs(end)*0.01))+exrad(ceil(M5_locs(end)*0.01))-1),...
    subxx(ceil(M5_locs(end)*0.01)):(subxx(ceil(M5_locs(end)*0.01))+...
    exkol(ceil(M5_locs(end)*0.01))-1),ste) = 9;
ar_con4_all(subyy(ceil(M5_locs(end)*0.005)):...
    (subyy(ceil(M5_locs(end)*0.005))+exrad(ceil(M5_locs(end)*0.005))-1),...
    subxx(ceil(M5_locs(end)*0.005)):(subxx(ceil(M5_locs(end)*0.005))+...
    exkol(ceil(M5_locs(end)*0.005))-1),ste) = 10;
               
 PRINT_CALC = sprintf('Calculated SPACs for TIME-STEPS:    %d/9',ste);
 disp(PRINT_CALC)
end
disp('Method 4 DONE')
